==> scala-k8s-objects_sjs1_3-0.3.0-sources.jar: io/k8s/api/scheduling/v1/PriorityClassList.scala <==
package io.k8s.api.scheduling.v1

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** PriorityClassList is a collection of priority classes. */
final case class PriorityClassList(
  items : Seq[io.k8s.api.scheduling.v1.PriorityClass],
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("scheduling.k8s.io", "PriorityClassList", "v1")


  /** Returns a new data with items set to new value */
  def withItems(value: Seq[io.k8s.api.scheduling.v1.PriorityClass]) : PriorityClassList = copy(items = value)
  /** Appends new values to items */
  def addItems(newValues: io.k8s.api.scheduling.v1.PriorityClass*) : PriorityClassList = copy(items = items ++ newValues)
  /** transforms items to result of function */
  def mapItems(f: Seq[io.k8s.api.scheduling.v1.PriorityClass] => Seq[io.k8s.api.scheduling.v1.PriorityClass]) : PriorityClassList = copy(items = f(items))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : PriorityClassList = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : PriorityClassList = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = PriorityClassList.encoder[T].apply(this)
}

object PriorityClassList {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.scheduling.v1.PriorityClassList, T] = new Encoder[io.k8s.api.scheduling.v1.PriorityClassList, T] {
        def apply(o: io.k8s.api.scheduling.v1.PriorityClassList) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("items", o.items)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, PriorityClassList] = new Decoder[T, PriorityClassList] {
      def apply(t: T): Either[String, PriorityClassList] = for {
          obj <- ObjectReader(t)
          items <- obj.read[Seq[io.k8s.api.scheduling.v1.PriorityClass]]("items")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta]("metadata")
      } yield PriorityClassList (
          items = items,
          metadata = metadata
        )
    }
}

==> scala-k8s-objects_sjs1_3-0.5.1-sources.jar: io/k8s/api/scheduling/v1/PriorityClassList.scala <==
package io.k8s.api.scheduling.v1

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** PriorityClassList is a collection of priority classes. */
final case class PriorityClassList(
  items : Seq[io.k8s.api.scheduling.v1.PriorityClass],
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("scheduling.k8s.io", "PriorityClassList", "v1")


  /** Returns a new data with items set to new value */
  def withItems(value: Seq[io.k8s.api.scheduling.v1.PriorityClass]) : PriorityClassList = copy(items = value)
  /** Appends new values to items */
  def addItems(newValues: io.k8s.api.scheduling.v1.PriorityClass*) : PriorityClassList = copy(items = items ++ newValues)
  /** transforms items to result of function */
  def mapItems(f: Seq[io.k8s.api.scheduling.v1.PriorityClass] => Seq[io.k8s.api.scheduling.v1.PriorityClass]) : PriorityClassList = copy(items = f(items))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : PriorityClassList = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : PriorityClassList = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = PriorityClassList.encoder.apply(this)
}

object PriorityClassList {

    implicit val encoder : Encoder[io.k8s.api.scheduling.v1.PriorityClassList] = new Encoder[io.k8s.api.scheduling.v1.PriorityClassList] {
        def apply[T : Builder](o: io.k8s.api.scheduling.v1.PriorityClassList) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("items", o.items)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit val decoder: Decoder[PriorityClassList] = new Decoder[PriorityClassList] {
      def apply[T : Reader](t: T): Either[String, PriorityClassList] = for {
          obj <- ObjectReader(t)
          items <- obj.read[Seq[io.k8s.api.scheduling.v1.PriorityClass]]("items")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta]("metadata")
      } yield PriorityClassList (
          items = items,
          metadata = metadata
        )
    }
}
